@@ -41,7 +41,7 @@ from oidcmsg.message import msg_ser
 from oidcmsg.oauth2 import ResponseMessage
 from oidcmsg.time_util import utc_time_sans_frac
 
-__author__ = 'Roland Hedberg'
+__author__ = "Roland Hedberg"
 
 logger = logging.getLogger(__name__)
 
@@ -66,18 +66,18 @@ class IATError(VerificationError):
 
 def deserialize_from_one_of(val, msgtype, sformat):
     if sformat in ["dict", "json"]:
-        flist = ['json', 'urlencoded']
+        flist = ["json", "urlencoded"]
         if not isinstance(val, str):
             val = json.dumps(val)
     else:
-        flist = ['urlencoded', 'json']
+        flist = ["urlencoded", "json"]
 
     for _format in flist:
         try:
             return msgtype().deserialize(val, _format)
         except FormatError:
             pass
-    raise FormatError('Unexpected format')
+    raise FormatError("Unexpected format")
 
 
 def json_ser(val, sformat=None, lev=0):
@@ -179,7 +179,7 @@ def claims_request_deser(val, sformat="json"):
         if not isinstance(val, str):
             val = json.dumps(val)
             sformat = "json"
-    elif sformat == 'dict':
+    elif sformat == "dict":
         if isinstance(val, str):
             val = json.loads(val)
 
@@ -209,10 +209,8 @@ OPTIONAL_MULTIPLE_Claims = (Message, False, claims_ser, claims_deser, False)
 SINGLE_OPTIONAL_IDTOKEN = (Message, False, msg_ser, None, False)
 SINGLE_REQUIRED_IDTOKEN = (Message, True, msg_ser, None, False)
 
-SINGLE_OPTIONAL_REGISTRATION_REQUEST = (Message, False, msg_ser,
-                                        registration_request_deser, False)
-SINGLE_OPTIONAL_CLAIMSREQ = (Message, False, msg_ser_json, claims_request_deser,
-                             False)
+SINGLE_OPTIONAL_REGISTRATION_REQUEST = (Message, False, msg_ser, registration_request_deser, False)
+SINGLE_OPTIONAL_CLAIMSREQ = (Message, False, msg_ser_json, claims_request_deser, False)
 
 SINGLE_OPTIONAL_DICT = (dict, False, msg_ser_json, dict_deser, False)
 
@@ -220,7 +218,7 @@ SINGLE_OPTIONAL_DICT = (dict, False, msg_ser_json, dict_deser, False)
 
 
 SCOPE_CHARSET = []
-for char in ['\x21', ('\x23', '\x5b'), ('\x5d', '\x7E')]:
+for char in ["\x21", ("\x23", "\x5b"), ("\x5d", "\x7E")]:
     if isinstance(char, tuple):
         c = char[0]
         while c <= char[1]:
@@ -238,12 +236,24 @@ def check_char_set(string, allowed):
 
 # -----------------------------------------------------------------------------
 
-ID_TOKEN_VERIFY_ARGS = ['keyjar', 'verify', 'encalg', 'encenc', 'sigalg',
-                        'issuer', 'allow_missing_kid', 'no_kid_issuer',
-                        'trusting', 'skew', 'nonce_storage_time', 'client_id',
-                        'allow_sign_alg_none', 'allowed_sign_alg']
+ID_TOKEN_VERIFY_ARGS = [
+    "keyjar",
+    "verify",
+    "encalg",
+    "encenc",
+    "sigalg",
+    "issuer",
+    "allow_missing_kid",
+    "no_kid_issuer",
+    "trusting",
+    "skew",
+    "nonce_storage_time",
+    "client_id",
+    "allow_sign_alg_none",
+    "allowed_sign_alg",
+]
 
-CLAIMS_WITH_VERIFIED = ['id_token', 'id_token_hint', 'request']
+CLAIMS_WITH_VERIFIED = ["id_token", "id_token_hint", "request"]
 
 
 def clear_verified_claims(msg):
@@ -264,7 +274,7 @@ class TokenErrorResponse(oauth2.TokenErrorResponse):
     pass
 
 
-def verify_id_token(msg, check_hash=False, claim='id_token', **kwargs):
+def verify_id_token(msg, check_hash=False, claim="id_token", **kwargs):
     # Try to decode the JWT, checks the signature
     args = {}
     for arg in ID_TOKEN_VERIFY_ARGS:
@@ -275,34 +285,35 @@ def verify_id_token(msg, check_hash=False, claim='id_token', **kwargs):
 
     _jws = jws_factory(msg[claim])
     if not _jws:
-        raise ValueError('{} not a signed JWT'.format(claim))
+        raise ValueError("{} not a signed JWT".format(claim))
 
-    if _jws.jwt.headers['alg'] == 'none':
+    if _jws.jwt.headers["alg"] == "none":
         _signed = False
         _sign_alg = kwargs.get("sigalg")
         if _sign_alg == "none":
             _allowed = True
         else:  # There might or might not be a specified signing alg
-            if kwargs.get('allow_sign_alg_none', False) is False:
-                logger.info('Signing algorithm None not allowed')
-                raise UnsupportedAlgorithm('Signing algorithm None not allowed')
+            if kwargs.get("allow_sign_alg_none", False) is False:
+                logger.info("Signing algorithm None not allowed")
+                raise UnsupportedAlgorithm("Signing algorithm None not allowed")
     else:
         _signed = True
         if "allowed_sign_alg" in kwargs:
-            if _jws.jwt.headers['alg'] != kwargs["allowed_sign_alg"]:
+            if _jws.jwt.headers["alg"] != kwargs["allowed_sign_alg"]:
                 _msg = "Wrong token signing algorithm, {} != {}".format(
-                    _jws.jwt.headers['alg'], kwargs["allowed_sign_alg"])
+                    _jws.jwt.headers["alg"], kwargs["allowed_sign_alg"]
+                )
                 logger.error(_msg)
                 raise UnsupportedAlgorithm(_msg)
 
     _body = _jws.jwt.payload()
-    if _signed and 'keyjar' in kwargs:
+    if _signed and "keyjar" in kwargs:
         try:
-            if _body['iss'] not in kwargs['keyjar']:
-                logger.info('KeyJar issuers: {}'.format(kwargs['keyjar']))
-                raise ValueError('Unknown issuer: "{}"'.format(_body['iss']))
+            if _body["iss"] not in kwargs["keyjar"]:
+                logger.info("KeyJar issuers: {}".format(kwargs["keyjar"]))
+                raise ValueError('Unknown issuer: "{}"'.format(_body["iss"]))
         except KeyError:
-            raise MissingRequiredAttribute('iss')
+            raise MissingRequiredAttribute("iss")
 
     idt = IdToken().from_jwt(str(msg[claim]), **args)
     if not idt.verify(**kwargs):
@@ -314,22 +325,18 @@ def verify_id_token(msg, check_hash=False, claim='id_token', **kwargs):
 
         if "access_token" in msg:
             if "at_hash" not in idt:
-                raise MissingRequiredAttribute("Missing at_hash property",
-                                               idt)
-            if idt["at_hash"] != left_hash(msg["access_token"],
-                                           hfunc):
-                raise AtHashError(
-                    "Failed to verify access_token hash", idt)
+                raise MissingRequiredAttribute("Missing at_hash property", idt)
+            if idt["at_hash"] != left_hash(msg["access_token"], hfunc):
+                raise AtHashError("Failed to verify access_token hash", idt)
 
         if "code" in msg:
             if "c_hash" not in idt:
-                raise MissingRequiredAttribute("Missing c_hash property",
-                                               idt)
+                raise MissingRequiredAttribute("Missing c_hash property", idt)
             if idt["c_hash"] != left_hash(msg["code"], hfunc):
                 raise CHashError("Failed to verify code hash", idt)
 
     msg[verified_claim_name(claim)] = idt
-    logger.info('Verified {}: {}'.format(claim, idt.to_dict()))
+    logger.info("Verified {}: {}".format(claim, idt.to_dict()))
 
     return True
 
@@ -356,19 +363,20 @@ class UserInfoRequest(Message):
     }
 
 
-class AuthorizationResponse(oauth2.AuthorizationResponse,
-                            oauth2.AccessTokenResponse):
+class AuthorizationResponse(oauth2.AuthorizationResponse, oauth2.AccessTokenResponse):
     c_param = oauth2.AuthorizationResponse.c_param.copy()
     c_param.update(oauth2.AccessTokenResponse.c_param)
-    c_param.update({
-        "code": SINGLE_OPTIONAL_STRING,
-        # "nonce": SINGLE_OPTIONAL_STRING,
-        "access_token": SINGLE_OPTIONAL_STRING,
-        "token_type": SINGLE_OPTIONAL_STRING,
-        "id_token": SINGLE_OPTIONAL_IDTOKEN,
-        # Below is REQUIRED if doing session management
-        "session_state": SINGLE_OPTIONAL_STRING
-    })
+    c_param.update(
+        {
+            "code": SINGLE_OPTIONAL_STRING,
+            # "nonce": SINGLE_OPTIONAL_STRING,
+            "access_token": SINGLE_OPTIONAL_STRING,
+            "token_type": SINGLE_OPTIONAL_STRING,
+            "id_token": SINGLE_OPTIONAL_IDTOKEN,
+            # Below is REQUIRED if doing session management
+            "session_state": SINGLE_OPTIONAL_STRING,
+        }
+    )
 
     def verify(self, **kwargs):
         super(AuthorizationResponse, self).verify(**kwargs)
@@ -388,17 +396,20 @@ class AuthorizationResponse(oauth2.AuthorizationResponse,
 
 
 class AuthorizationErrorResponse(oauth2.AuthorizationErrorResponse):
-    c_allowed_values = oauth2.AuthorizationErrorResponse.c_allowed_values \
-        .copy()
-    c_allowed_values["error"].extend(["interaction_required",
-                                      "login_required",
-                                      "session_selection_required",
-                                      "consent_required",
-                                      "invalid_request_uri",
-                                      "invalid_request_object",
-                                      "registration_not_supported",
-                                      "request_not_supported",
-                                      "request_uri_not_supported"])
+    c_allowed_values = oauth2.AuthorizationErrorResponse.c_allowed_values.copy()
+    c_allowed_values["error"].extend(
+        [
+            "interaction_required",
+            "login_required",
+            "session_selection_required",
+            "consent_required",
+            "invalid_request_uri",
+            "invalid_request_object",
+            "registration_not_supported",
+            "request_not_supported",
+            "request_uri_not_supported",
+        ]
+    )
 
 
 class AuthorizationRequest(oauth2.AuthorizationRequest):
@@ -425,10 +436,12 @@ class AuthorizationRequest(oauth2.AuthorizationRequest):
         }
     )
     c_allowed_values = oauth2.AuthorizationRequest.c_allowed_values.copy()
-    c_allowed_values.update({
-        "display": ["page", "popup", "touch", "wap"],
-        "prompt": ["none", "login", "consent", "select_account"]
-    })
+    c_allowed_values.update(
+        {
+            "display": ["page", "popup", "touch", "wap"],
+            "prompt": ["none", "login", "consent", "select_account"],
+        }
+    )
 
     def verify(self, **kwargs):
         """Authorization Request parameters that are OPTIONAL in the OAuth 2.0
@@ -444,8 +457,7 @@ class AuthorizationRequest(oauth2.AuthorizationRequest):
         clear_verified_claims(self)
 
         args = {}
-        for arg in ["keyjar", "opponent_id", "sender", "alg", "encalg",
-                    "encenc"]:
+        for arg in ["keyjar", "opponent_id", "sender", "alg", "encalg", "encenc"]:
             try:
                 args[arg] = kwargs[arg]
             except KeyError:
@@ -464,7 +476,7 @@ class AuthorizationRequest(oauth2.AuthorizationRequest):
                     if key in self:
                         if self[key] != val:
                             # log but otherwise ignore
-                            logger.warning('{} != {}'.format(self[key], val))
+                            logger.warning("{} != {}".format(self[key], val))
 
                 # remove all claims
                 _keys = list(self.keys())
@@ -491,10 +503,8 @@ class AuthorizationRequest(oauth2.AuthorizationRequest):
                 raise MissingRequiredAttribute("Nonce missing", self)
             else:
                 try:
-                    if self['nonce'] != kwargs['nonce']:
-                        raise ValueError(
-                            'Nonce in id_token not matching nonce in authz '
-                            'request')
+                    if self["nonce"] != kwargs["nonce"]:
+                        raise ValueError("Nonce in id_token not matching nonce in authz " "request")
                 except KeyError:
                     pass
 
@@ -507,22 +517,22 @@ class AuthorizationRequest(oauth2.AuthorizationRequest):
 
         if "prompt" in self:
             if "none" in self["prompt"] and len(self["prompt"]) > 1:
-                raise InvalidRequest("prompt none combined with other value",
-                                     self)
+                raise InvalidRequest("prompt none combined with other value", self)
 
         return True
 
 
 class AccessTokenRequest(oauth2.AccessTokenRequest):
     c_param = oauth2.AccessTokenRequest.c_param.copy()
-    c_param.update({
-        "client_assertion_type": SINGLE_OPTIONAL_STRING,
-        "client_assertion": SINGLE_OPTIONAL_STRING
-    })
+    c_param.update(
+        {
+            "client_assertion_type": SINGLE_OPTIONAL_STRING,
+            "client_assertion": SINGLE_OPTIONAL_STRING,
+        }
+    )
     c_default = {"grant_type": "authorization_code"}
     c_allowed_values = {
-        "client_assertion_type": [
-            "urn:ietf:params:oauth:client-assertion-type:jwt-bearer"],
+        "client_assertion_type": ["urn:ietf:params:oauth:client-assertion-type:jwt-bearer"],
     }
 
 
@@ -533,7 +543,7 @@ class AddressClaim(Message):
         "locality": SINGLE_OPTIONAL_STRING,
         "region": SINGLE_OPTIONAL_STRING,
         "postal_code": SINGLE_OPTIONAL_STRING,
-        "country": SINGLE_OPTIONAL_STRING
+        "country": SINGLE_OPTIONAL_STRING,
     }
 
 
@@ -562,8 +572,9 @@ class OpenIDSchema(ResponseMessage):
             "address": OPTIONAL_ADDRESS,
             "updated_at": SINGLE_OPTIONAL_INT,
             "_claim_names": OPTIONAL_MESSAGE,
-            "_claim_sources": OPTIONAL_MESSAGE
-        })
+            "_claim_sources": OPTIONAL_MESSAGE,
+        }
+    )
 
     def verify(self, **kwargs):
         super(OpenIDSchema, self).verify(**kwargs)
@@ -628,12 +639,12 @@ class RegistrationRequest(Message):
         "backchannel_logout_uri": SINGLE_OPTIONAL_STRING,
         "backchannel_logout_session_supported": SINGLE_OPTIONAL_BOOLEAN,
         "federation_type": OPTIONAL_LIST_OF_STRINGS,
-        "organization_name": SINGLE_OPTIONAL_STRING
+        "organization_name": SINGLE_OPTIONAL_STRING,
     }
     c_default = {"application_type": "web", "response_types": ["code"]}
     c_allowed_values = {
         "application_type": ["native", "web"],
-        "subject_type": ["public", "pairwise"]
+        "subject_type": ["public", "pairwise"],
     }
 
     def verify(self, **kwargs):
@@ -641,11 +652,13 @@ class RegistrationRequest(Message):
 
         if "initiate_login_uri" in self:
             if not self["initiate_login_uri"].startswith("https:"):
-                raise ValueError('Wrong scheme')
+                raise ValueError("Wrong scheme")
 
-        for param in ["request_object_encryption",
-                      "id_token_encrypted_response",
-                      "userinfo_encrypted_response"]:
+        for param in [
+            "request_object_encryption",
+            "id_token_encrypted_response",
+            "userinfo_encrypted_response",
+        ]:
             alg_param = "%s_alg" % param
             enc_param = "%s_enc" % param
             if alg_param in self:
@@ -655,7 +668,7 @@ class RegistrationRequest(Message):
             # both or none
             if enc_param in self:
                 if alg_param not in self:
-                    raise MissingRequiredAttribute('alg_param')
+                    raise MissingRequiredAttribute("alg_param")
 
         if "token_endpoint_auth_signing_alg" in self:
             if self["token_endpoint_auth_signing_alg"] == "none":
@@ -668,6 +681,7 @@ class RegistrationResponse(ResponseMessage):
     """
     Response to client_register registration requests
     """
+
     c_param = ResponseMessage.c_param.copy()
     c_param.update(
         {
@@ -676,8 +690,9 @@ class RegistrationResponse(ResponseMessage):
             "registration_access_token": SINGLE_OPTIONAL_STRING,
             "registration_client_uri": SINGLE_OPTIONAL_STRING,
             "client_id_issued_at": SINGLE_OPTIONAL_INT,
-            "client_secret_expires_at": SINGLE_OPTIONAL_INT
-        })
+            "client_secret_expires_at": SINGLE_OPTIONAL_INT,
+        }
+    )
     c_param.update(RegistrationRequest.c_param)
 
     def verify(self, **kwargs):
@@ -692,40 +707,45 @@ class RegistrationResponse(ResponseMessage):
         has_reg_uri = "registration_client_uri" in self
         has_reg_at = "registration_access_token" in self
         if has_reg_uri != has_reg_at:
-            raise VerificationError((
-                "Only one of registration_client_uri"
-                " and registration_access_token present"), self)
+            raise VerificationError(
+                ("Only one of registration_client_uri" " and registration_access_token present"),
+                self,
+            )
 
         return True
 
 
 class ClientRegistrationErrorResponse(oauth2.ResponseMessage):
     c_allowed_values = {
-        "error": ["invalid_redirect_uri",
-                  "invalid_client_metadata",
-                  "invalid_configuration_parameter"]
+        "error": [
+            "invalid_redirect_uri",
+            "invalid_client_metadata",
+            "invalid_configuration_parameter",
+        ]
     }
 
 
 class IdToken(OpenIDSchema):
     c_param = OpenIDSchema.c_param.copy()
-    c_param.update({
-        "iss": SINGLE_REQUIRED_STRING,
-        "sub": SINGLE_REQUIRED_STRING,
-        "aud": REQUIRED_LIST_OF_STRINGS,  # Array of strings or string
-        "exp": SINGLE_REQUIRED_INT,
-        "iat": SINGLE_REQUIRED_INT,
-        "auth_time": SINGLE_OPTIONAL_INT,
-        "nonce": SINGLE_OPTIONAL_STRING,
-        "at_hash": SINGLE_OPTIONAL_STRING,
-        "c_hash": SINGLE_OPTIONAL_STRING,
-        "acr": SINGLE_OPTIONAL_STRING,
-        "amr": OPTIONAL_LIST_OF_STRINGS,
-        "azp": SINGLE_OPTIONAL_STRING,
-        "sub_jwk": SINGLE_OPTIONAL_STRING,
-        "sid": SINGLE_OPTIONAL_STRING
-    })
-    hashable = {'access_token': 'at_hash', 'code': 'c_hash'}
+    c_param.update(
+        {
+            "iss": SINGLE_REQUIRED_STRING,
+            "sub": SINGLE_REQUIRED_STRING,
+            "aud": REQUIRED_LIST_OF_STRINGS,  # Array of strings or string
+            "exp": SINGLE_REQUIRED_INT,
+            "iat": SINGLE_REQUIRED_INT,
+            "auth_time": SINGLE_OPTIONAL_INT,
+            "nonce": SINGLE_OPTIONAL_STRING,
+            "at_hash": SINGLE_OPTIONAL_STRING,
+            "c_hash": SINGLE_OPTIONAL_STRING,
+            "acr": SINGLE_OPTIONAL_STRING,
+            "amr": OPTIONAL_LIST_OF_STRINGS,
+            "azp": SINGLE_OPTIONAL_STRING,
+            "sub_jwk": SINGLE_OPTIONAL_STRING,
+            "sid": SINGLE_OPTIONAL_STRING,
+        }
+    )
+    hashable = {"access_token": "at_hash", "code": "c_hash"}
 
     def val_hash(self, alg):
         halg = "HS%s" % alg[-3:]
@@ -739,15 +759,15 @@ class IdToken(OpenIDSchema):
                 del self[attr]
 
     def pack_init(self, lifetime=0):
-        self['iat'] = utc_time_sans_frac()
+        self["iat"] = utc_time_sans_frac()
         if lifetime:
-            self['exp'] = self['iat'] + lifetime
+            self["exp"] = self["iat"] + lifetime
 
-    def pack(self, alg='', **kwargs):
+    def pack(self, alg="", **kwargs):
         self.val_hash(alg)
 
-        if 'lifetime' in kwargs:
-            self.pack_init(kwargs['lifetime'])
+        if "lifetime" in kwargs:
+            self.pack_init(kwargs["lifetime"])
         else:
             self.pack_init()
 
@@ -767,9 +787,8 @@ class IdToken(OpenIDSchema):
         super(IdToken, self).verify(**kwargs)
 
         try:
-            if kwargs['iss'] != self['iss']:
-                raise IssuerMismatch(
-                    '{} != {}'.format(kwargs['iss'], self['iss']))
+            if kwargs["iss"] != self["iss"]:
+                raise IssuerMismatch("{} != {}".format(kwargs["iss"], self["iss"]))
         except KeyError:
             pass
 
@@ -778,61 +797,58 @@ class IdToken(OpenIDSchema):
                 # check that I'm among the recipients
                 if kwargs["client_id"] not in self["aud"]:
                     raise NotForMe(
-                        "{} not in aud:{}".format(kwargs["client_id"],
-                                                  self["aud"]), self)
+                        "{} not in aud:{}".format(kwargs["client_id"], self["aud"]), self
+                    )
 
             # Then azp has to be present and be one of the aud values
             if len(self["aud"]) > 1:
                 if "azp" in self:
                     if self["azp"] not in self["aud"]:
-                        raise VerificationError(
-                            "Mismatch between azp and aud claims", self)
+                        raise VerificationError("Mismatch between azp and aud claims", self)
                 else:
                     raise VerificationError("azp missing", self)
 
         if "azp" in self:
             if "client_id" in kwargs:
                 if kwargs["client_id"] != self["azp"]:
-                    raise NotForMe(
-                        "{} != azp:{}".format(kwargs["client_id"],
-                                              self["azp"]), self)
+                    raise NotForMe("{} != azp:{}".format(kwargs["client_id"], self["azp"]), self)
 
         _now = time_util.utc_time_sans_frac()
 
         try:
-            _skew = kwargs['skew']
+            _skew = kwargs["skew"]
         except KeyError:
             _skew = 0
 
         try:
-            _exp = self['exp']
+            _exp = self["exp"]
         except KeyError:
-            raise MissingRequiredAttribute('exp')
+            raise MissingRequiredAttribute("exp")
         else:
             if (_now - _skew) > _exp:
-                raise EXPError('Invalid expiration time')
+                raise EXPError("Invalid expiration time")
 
         try:
-            _storage_time = kwargs['nonce_storage_time']
+            _storage_time = kwargs["nonce_storage_time"]
         except KeyError:
             _storage_time = NONCE_STORAGE_TIME
 
         try:
-            _iat = self['iat']
+            _iat = self["iat"]
         except KeyError:
-            raise MissingRequiredAttribute('iat')
+            raise MissingRequiredAttribute("iat")
         else:
             if (_iat + _storage_time) < (_now - _skew):
-                raise IATError('Issued too long ago')
+                raise IATError("Issued too long ago")
             elif _iat > _now + _skew:
-                raise IATError('Issued sometime in the future')
+                raise IATError("Issued sometime in the future")
 
         if _exp < _iat:
-            raise IATError('Expiration time can not be earlier the issued at')
+            raise IATError("Expiration time can not be earlier the issued at")
 
-        if 'nonce' in kwargs and 'nonce' in self:
-            if kwargs['nonce'] != self['nonce']:
-                raise ValueError('Not the same nonce')
+        if "nonce" in kwargs and "nonce" in self:
+            if kwargs["nonce"] != self["nonce"]:
+                raise ValueError("Not the same nonce")
 
         return True
 
@@ -855,64 +871,62 @@ class OpenIDRequest(AuthorizationRequest):
 
 class ProviderConfigurationResponse(ResponseMessage):
     c_param = ResponseMessage.c_param.copy()
-    c_param.update({
-        "issuer": SINGLE_REQUIRED_STRING,
-        "authorization_endpoint": SINGLE_REQUIRED_STRING,
-        "token_endpoint": SINGLE_OPTIONAL_STRING,
-        "userinfo_endpoint": SINGLE_OPTIONAL_STRING,
-        "jwks_uri": SINGLE_REQUIRED_STRING,
-        "registration_endpoint": SINGLE_OPTIONAL_STRING,
-        "scopes_supported": OPTIONAL_LIST_OF_STRINGS,
-        "response_types_supported": REQUIRED_LIST_OF_STRINGS,
-        "response_modes_supported": OPTIONAL_LIST_OF_STRINGS,
-        "grant_types_supported": OPTIONAL_LIST_OF_STRINGS,
-        "acr_values_supported": OPTIONAL_LIST_OF_STRINGS,
-        "subject_types_supported": REQUIRED_LIST_OF_STRINGS,
-        "id_token_signing_alg_values_supported": REQUIRED_LIST_OF_STRINGS,
-        "id_token_encryption_alg_values_supported": OPTIONAL_LIST_OF_STRINGS,
-        "id_token_encryption_enc_values_supported": OPTIONAL_LIST_OF_STRINGS,
-        "userinfo_signing_alg_values_supported": OPTIONAL_LIST_OF_STRINGS,
-        "userinfo_encryption_alg_values_supported": OPTIONAL_LIST_OF_STRINGS,
-        "userinfo_encryption_enc_values_supported": OPTIONAL_LIST_OF_STRINGS,
-        "request_object_signing_alg_values_supported": OPTIONAL_LIST_OF_STRINGS,
-        "request_object_encryption_alg_values_supported":
-            OPTIONAL_LIST_OF_STRINGS,
-        "request_object_encryption_enc_values_supported":
-            OPTIONAL_LIST_OF_STRINGS,
-        "token_endpoint_auth_methods_supported": OPTIONAL_LIST_OF_STRINGS,
-        "token_endpoint_auth_signing_alg_values_supported":
-            OPTIONAL_LIST_OF_STRINGS,
-        "display_values_supported": OPTIONAL_LIST_OF_STRINGS,
-        "claim_types_supported": OPTIONAL_LIST_OF_STRINGS,
-        "claims_supported": OPTIONAL_LIST_OF_STRINGS,
-        "service_documentation": SINGLE_OPTIONAL_STRING,
-        "claims_locales_supported": OPTIONAL_LIST_OF_STRINGS,
-        "ui_locales_supported": OPTIONAL_LIST_OF_STRINGS,
-        "claims_parameter_supported": SINGLE_OPTIONAL_BOOLEAN,
-        "request_parameter_supported": SINGLE_OPTIONAL_BOOLEAN,
-        "request_uri_parameter_supported": SINGLE_OPTIONAL_BOOLEAN,
-        "require_request_uri_registration": SINGLE_OPTIONAL_BOOLEAN,
-        "op_policy_uri": SINGLE_OPTIONAL_STRING,
-        "op_tos_uri": SINGLE_OPTIONAL_STRING,
-        "check_session_iframe": SINGLE_OPTIONAL_STRING,
-        "end_session_endpoint": SINGLE_OPTIONAL_STRING,
-        "frontchannel_logout_supported": SINGLE_OPTIONAL_BOOLEAN,
-        "frontchannel_logout_session_supported": SINGLE_OPTIONAL_BOOLEAN,
-        "backchannel_logout_supported": SINGLE_OPTIONAL_BOOLEAN,
-        "backchannel_logout_session_supported": SINGLE_OPTIONAL_BOOLEAN
-        # "jwk_encryption_url": SINGLE_OPTIONAL_STRING,
-        # "x509_url": SINGLE_REQUIRED_STRING,
-        # "x509_encryption_url": SINGLE_OPTIONAL_STRING,
-    })
+    c_param.update(
+        {
+            "issuer": SINGLE_REQUIRED_STRING,
+            "authorization_endpoint": SINGLE_REQUIRED_STRING,
+            "token_endpoint": SINGLE_OPTIONAL_STRING,
+            "userinfo_endpoint": SINGLE_OPTIONAL_STRING,
+            "jwks_uri": SINGLE_REQUIRED_STRING,
+            "registration_endpoint": SINGLE_OPTIONAL_STRING,
+            "scopes_supported": OPTIONAL_LIST_OF_STRINGS,
+            "response_types_supported": REQUIRED_LIST_OF_STRINGS,
+            "response_modes_supported": OPTIONAL_LIST_OF_STRINGS,
+            "grant_types_supported": OPTIONAL_LIST_OF_STRINGS,
+            "acr_values_supported": OPTIONAL_LIST_OF_STRINGS,
+            "subject_types_supported": REQUIRED_LIST_OF_STRINGS,
+            "id_token_signing_alg_values_supported": REQUIRED_LIST_OF_STRINGS,
+            "id_token_encryption_alg_values_supported": OPTIONAL_LIST_OF_STRINGS,
+            "id_token_encryption_enc_values_supported": OPTIONAL_LIST_OF_STRINGS,
+            "userinfo_signing_alg_values_supported": OPTIONAL_LIST_OF_STRINGS,
+            "userinfo_encryption_alg_values_supported": OPTIONAL_LIST_OF_STRINGS,
+            "userinfo_encryption_enc_values_supported": OPTIONAL_LIST_OF_STRINGS,
+            "request_object_signing_alg_values_supported": OPTIONAL_LIST_OF_STRINGS,
+            "request_object_encryption_alg_values_supported": OPTIONAL_LIST_OF_STRINGS,
+            "request_object_encryption_enc_values_supported": OPTIONAL_LIST_OF_STRINGS,
+            "token_endpoint_auth_methods_supported": OPTIONAL_LIST_OF_STRINGS,
+            "token_endpoint_auth_signing_alg_values_supported": OPTIONAL_LIST_OF_STRINGS,
+            "display_values_supported": OPTIONAL_LIST_OF_STRINGS,
+            "claim_types_supported": OPTIONAL_LIST_OF_STRINGS,
+            "claims_supported": OPTIONAL_LIST_OF_STRINGS,
+            "service_documentation": SINGLE_OPTIONAL_STRING,
+            "claims_locales_supported": OPTIONAL_LIST_OF_STRINGS,
+            "ui_locales_supported": OPTIONAL_LIST_OF_STRINGS,
+            "claims_parameter_supported": SINGLE_OPTIONAL_BOOLEAN,
+            "request_parameter_supported": SINGLE_OPTIONAL_BOOLEAN,
+            "request_uri_parameter_supported": SINGLE_OPTIONAL_BOOLEAN,
+            "require_request_uri_registration": SINGLE_OPTIONAL_BOOLEAN,
+            "op_policy_uri": SINGLE_OPTIONAL_STRING,
+            "op_tos_uri": SINGLE_OPTIONAL_STRING,
+            "check_session_iframe": SINGLE_OPTIONAL_STRING,
+            "end_session_endpoint": SINGLE_OPTIONAL_STRING,
+            "frontchannel_logout_supported": SINGLE_OPTIONAL_BOOLEAN,
+            "frontchannel_logout_session_supported": SINGLE_OPTIONAL_BOOLEAN,
+            "backchannel_logout_supported": SINGLE_OPTIONAL_BOOLEAN,
+            "backchannel_logout_session_supported": SINGLE_OPTIONAL_BOOLEAN
+            # "jwk_encryption_url": SINGLE_OPTIONAL_STRING,
+            # "x509_url": SINGLE_REQUIRED_STRING,
+            # "x509_encryption_url": SINGLE_OPTIONAL_STRING,
+        }
+    )
     c_default = {
         "version": "3.0",
-        "token_endpoint_auth_methods_supported": [
-            "client_secret_basic"],
+        "token_endpoint_auth_methods_supported": ["client_secret_basic"],
         "claims_parameter_supported": False,
         "request_parameter_supported": False,
         "request_uri_parameter_supported": True,
         "require_request_uri_registration": True,
-        "grant_types_supported": ["authorization_code", "implicit"]
+        "grant_types_supported": ["authorization_code", "implicit"],
     }
 
     def verify(self, **kwargs):
@@ -925,29 +939,33 @@ class ProviderConfigurationResponse(ResponseMessage):
                 check_char_set(scope, SCOPE_CHARSET)
 
         parts = urlparse(self["issuer"])
-        if 'allow_http' in kwargs:
+        if "allow_http" in kwargs:
             pass
         elif parts.scheme != "https":
             raise SchemeError("Not HTTPS")
 
         # The parameter is optional
-        if "token_endpoint_auth_signing_alg_values_supported" in self and "none" in self[
-                "token_endpoint_auth_signing_alg_values_supported"]:
+        if (
+            "token_endpoint_auth_signing_alg_values_supported" in self
+            and "none" in self["token_endpoint_auth_signing_alg_values_supported"]
+        ):
             raise ValueError(
                 "The value none must not be used for "
                 "token_endpoint_auth_signing_alg_values_supported"
             )
 
         if "RS256" not in self["id_token_signing_alg_values_supported"]:
-            raise ValueError('RS256 missing from id_token_signing_alg_values_supported')
+            raise ValueError("RS256 missing from id_token_signing_alg_values_supported")
 
         if not parts.query and not parts.fragment:
             pass
         else:
-            raise ValueError('Issuer ID invalid')
+            raise ValueError("Issuer ID invalid")
 
-        if any("code" in rt for rt in self[
-                "response_types_supported"]) and "token_endpoint" not in self:
+        if (
+            any("code" in rt for rt in self["response_types_supported"])
+            and "token_endpoint" not in self
+        ):
             raise MissingRequiredAttribute("token_endpoint")
 
         return True
@@ -971,48 +989,48 @@ class JsonWebToken(Message):
         _now = utc_time_sans_frac()
 
         try:
-            _skew = kwargs['skew']
+            _skew = kwargs["skew"]
         except KeyError:
             _skew = 0
 
         try:
-            _exp = self['exp']
+            _exp = self["exp"]
         except KeyError:
             pass
         else:
             if (_now - _skew) > _exp:
-                raise EXPError('Invalid expiration time')
+                raise EXPError("Invalid expiration time")
 
         try:
-            _iat = self['iat']
+            _iat = self["iat"]
         except KeyError:
             pass
         else:
             if _iat > (_now + _skew):
-                raise EXPError('Invalid issued-at time')
+                raise EXPError("Invalid issued-at time")
 
         try:
-            _nbf = self['nbf']
+            _nbf = self["nbf"]
         except KeyError:
             pass
         else:
             if _nbf > (_now - _skew):
-                raise EXPError('Not valid yet')
+                raise EXPError("Not valid yet")
 
         try:
-            _aud = self['aud']
+            _aud = self["aud"]
         except KeyError:
             pass
         else:
             try:
-                if kwargs['aud'] not in _aud:
-                    raise NotForMe('Not among intended audience')
+                if kwargs["aud"] not in _aud:
+                    raise NotForMe("Not among intended audience")
             except KeyError:
                 pass
 
-        if 'iss' in kwargs and 'iss' in self:
-            if kwargs['iss'] != self['iss']:
-                raise ValueError('Wrong issuer')
+        if "iss" in kwargs and "iss" in self:
+            if kwargs["iss"] != self["iss"]:
+                raise ValueError("Wrong issuer")
 
         return True
 
@@ -1043,28 +1061,25 @@ SINGLE_OPTIONAL_JWT = (Message, False, msg_ser, jwt_deser, False)
 
 class UserInfoErrorResponse(oauth2.ResponseMessage):
     c_allowed_values = {
-        "error": ["invalid_schema", "invalid_request",
-                  "invalid_token", "insufficient_scope"]
+        "error": ["invalid_schema", "invalid_request", "invalid_token", "insufficient_scope"]
     }
 
 
 class DiscoveryRequest(Message):
-    c_param = {
-        "resource": SINGLE_REQUIRED_STRING,
-        "rel": SINGLE_REQUIRED_STRING
-    }
+    c_param = {"resource": SINGLE_REQUIRED_STRING, "rel": SINGLE_REQUIRED_STRING}
 
 
 class Link(Message):
     """
     https://tools.ietf.org/html/rfc5988
     """
+
     c_param = {
         "rel": SINGLE_REQUIRED_STRING,
         "type": SINGLE_OPTIONAL_STRING,
         "href": SINGLE_OPTIONAL_STRING,
         "titles": SINGLE_OPTIONAL_DICT,
-        "properties": SINGLE_OPTIONAL_DICT
+        "properties": SINGLE_OPTIONAL_DICT,
     }
 
 
@@ -1088,7 +1103,7 @@ def link_deser(val, sformat="urlencoded"):
 def link_ser(inst, sformat, lev=0):
     if sformat in ["urlencoded", "json"]:
         if isinstance(inst, dict):
-            if sformat == 'json':
+            if sformat == "json":
                 res = json.dumps(inst)
             else:
                 res = urlencode([(k, v) for k, v in inst.items()])
@@ -1125,19 +1140,17 @@ class JRD(ResponseMessage):
     """
     JSON Resource Descriptor https://tools.ietf.org/html/rfc7033#section-4.4
     """
+
     c_param = {
         "subject": SINGLE_OPTIONAL_STRING,
         "aliases": OPTIONAL_LIST_OF_STRINGS,
         "properties": SINGLE_OPTIONAL_DICT,
-        "links": REQUIRED_LINKS
+        "links": REQUIRED_LINKS,
     }
 
 
 class WebFingerRequest(Message):
-    c_param = {
-        "resource": SINGLE_REQUIRED_STRING,
-        "rel": SINGLE_REQUIRED_STRING
-    }
+    c_param = {"resource": SINGLE_REQUIRED_STRING, "rel": SINGLE_REQUIRED_STRING}
     c_default = {"rel": "http://openid.net/specs/connect/1.0/issuer"}
 
 
@@ -1151,10 +1164,7 @@ class Claims(Message):
 
 
 class ClaimsRequest(Message):
-    c_param = {
-        "userinfo": OPTIONAL_MULTIPLE_Claims,
-        "id_token": OPTIONAL_MULTIPLE_Claims
-    }
+    c_param = {"userinfo": OPTIONAL_MULTIPLE_Claims, "id_token": OPTIONAL_MULTIPLE_Claims}
 
 
 def factory(msgtype, **kwargs):
@@ -1170,8 +1180,9 @@ def factory(msgtype, **kwargs):
     return oauth2.factory(msgtype, **kwargs)
 
 
-def make_openid_request(arq, keys, issuer, request_object_signing_alg, recv, with_jti=False,
-                        lifetime=0):
+def make_openid_request(
+    arq, keys, issuer, request_object_signing_alg, recv, with_jti=False, lifetime=0
+):
     """
     Construct the JWT to be passed by value (the request parameter) or by
     reference (request_uri).
@@ -1219,7 +1230,7 @@ def claims_match(value, claimspec):
         elif key == "values":
             if value in val:
                 matched = True
-        elif key == 'essential':
+        elif key == "essential":
             # Whether it's essential or not doesn't change anything here
             continue
 
@@ -1227,7 +1238,7 @@ def claims_match(value, claimspec):
             break
 
     # No values to test against so it's just about being there or not
-    if list(claimspec.keys()) == ['essential']:
+    if list(claimspec.keys()) == ["essential"]:
         return True
 
     return matched
